cleanx.report.finding

Finding constructors + redaction.

Finding constructors + redaction.
raw docstring

cleanx.report.json

Render scan results as JSON (or EDN).

Render scan results as JSON (or EDN).
raw docstring

cleanx.report.markdown

Render a scan result as a human-readable markdown report.

Render a scan result as a human-readable markdown report.
raw docstring

cleanx.report.remedy

Map a finding to a concrete remedy block (shell commands + guidance).

Map a finding to a concrete remedy block (shell commands + guidance).
raw docstring

cleanx.report.wipe

Render a wipe plan (or multiple) as markdown.

Render a wipe plan (or multiple) as markdown.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries