Clojure only.

cleanx.report.remedy

Map a finding to a concrete remedy block (shell commands + guidance).

Map a finding to a concrete remedy block (shell commands + guidance).
raw docstring

for-findingclj

(for-finding {:keys [kind] :as f})

Return a remedy string for a finding map.

Return a remedy string for a finding map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries