cleanx.scan.fs

Filesystem walk + stat. Thin layer over java.nio.file.

Filesystem walk + stat. Thin layer over java.nio.file.
raw docstring

->pathclj

(->path p)
source

perms->modeclj

(perms->mode perms)

Convert a set of PosixFilePermission into an integer octal mode.

Convert a set of PosixFilePermission into an integer octal mode.
sourceraw docstring

read-textclj

(read-text p)

Read file as UTF-8 string. Returns Result.

Read file as UTF-8 string. Returns Result.
sourceraw docstring

statclj

(stat p)

Return {:path :size :mode :dir? :symlink?} or nil if stat fails.

Return {:path :size :mode :dir? :symlink?} or nil if stat fails.
sourceraw docstring

walkclj

(walk root)
(walk root
      {:keys [max-size include-dotfiles? skip-binary?]
       :or {max-size (* 2 1024 1024) include-dotfiles? true skip-binary? true}})

Walk a directory tree, returning a lazy seq of stat maps for files only.

Options: :max-size — skip files larger than this many bytes (default 2 MB) :include-dotfiles? — default true :skip-binary? — default true

Walk a directory tree, returning a lazy seq of stat maps for files only.

Options:
  :max-size    — skip files larger than this many bytes (default 2 MB)
  :include-dotfiles? — default true
  :skip-binary?      — default true
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries