Filesystem walk + stat. Thin layer over java.nio.file.
Filesystem walk + stat. Thin layer over java.nio.file.
(perms->mode perms)Convert a set of PosixFilePermission into an integer octal mode.
Convert a set of PosixFilePermission into an integer octal mode.
(read-text p)Read file as UTF-8 string. Returns Result.
Read file as UTF-8 string. Returns Result.
(stat p)Return {:path :size :mode :dir? :symlink?} or nil if stat fails.
Return {:path :size :mode :dir? :symlink?} or nil if stat fails.
(walk root)(walk root
{:keys [max-size include-dotfiles? skip-binary?]
:or {max-size (* 2 1024 1024) include-dotfiles? true skip-binary? true}})Walk a directory tree, returning a lazy seq of stat maps for files only.
Options: :max-size — skip files larger than this many bytes (default 2 MB) :include-dotfiles? — default true :skip-binary? — default true
Walk a directory tree, returning a lazy seq of stat maps for files only. Options: :max-size — skip files larger than this many bytes (default 2 MB) :include-dotfiles? — default true :skip-binary? — default true
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |