Filesystem permission audit: compare actual modes against an expected-mode table for well-known sensitive paths.
Filesystem permission audit: compare actual modes against an expected-mode table for well-known sensitive paths.
(audit stats)Given a seq of stat maps, return a seq of violations. Each violation: {:path :mode :max-mode :severity :kind :evidence}.
Given a seq of stat maps, return a seq of violations.
Each violation: {:path :mode :max-mode :severity :kind :evidence}.Ordered list of {:glob :max-mode :severity :evidence} rules. First match wins.
Ordered list of {:glob :max-mode :severity :evidence} rules. First match wins.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |